@@ -1,5 +1,6 @@
 /*
     Copyright (C) 2017 Kai Uwe Broulik <kde@privat.broulik.de>
+    Copyright (C) 2018 David Edmundson <davidedmundson@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -46,9 +47,12 @@ function extensionCheckboxes() {
     return document.querySelectorAll("#extensions-selection input[type=checkbox][data-extension]");
 }
 
-function loadSettings() {
+function loadSettings(cb) {
     storage.get(DEFAULT_EXTENSION_SETTINGS, function (items) {
         if (chrome.runtime.lastError) {
+            if (typeof cb === "function") {
+                cb(false);
+            }
             return;
         }
 
@@ -68,6 +72,10 @@ function loadSettings() {
 
             // TODO restore additional stuff if we have it
         }
+
+        if (typeof cb === "function") {
+            cb(true);
+        }
     });
 }
 
@@ -129,23 +137,37 @@ document.addEventListener("DOMContentLoaded", function () {
         });
     }
 
-    loadSettings();
+    // check whether the platform is supported before loading and activating settings
+    chrome.runtime.getPlatformInfo(function (info) {
+        if (!SUPPORTED_PLATFORMS.includes(info.os)) {
+            document.body.classList.add("not-supported");
+            return;
+        }
 
-    // auto save when changing any setting
-    // TODO can we do that on closing, or does it not matter how often we do chrome storage sync thing?
-    document.querySelectorAll("input[type=checkbox]").forEach(function (item) {
-        item.addEventListener("click", function () {
-            var saveMessage = document.getElementById("save-message");
-            saveMessage.innerText = "";
+        loadSettings(function () {
+            var mpris = document.querySelector("[data-extension=mpris]");
+            var mprisEx = document.querySelector("[data-extension=mprisMediaSessions]");
+            mpris.addEventListener("change", function() {
+                mprisEx.disabled = !mpris.checked;
+            });
+            mprisEx.disabled = !mpris.checked;
+        });
 
-            saveSettings(function (error) {
-                if (error) {
-                    saveMessage.innerText = chrome.i18n.getMessage("options_save_failed");
-                    return;
-                }
+        // auto save when changing any setting
+        // TODO can we do that on closing, or does it not matter how often we do chrome storage sync thing?
+        document.querySelectorAll("input[type=checkbox]").forEach(function (item) {
+            item.addEventListener("click", function () {
+                var saveMessage = document.getElementById("save-message");
+                saveMessage.innerText = "";
 
-                //saveMessage.innerText = chrome.i18n.getMessage("options_save_success");
-                sendMessage("changed");
+                saveSettings(function (error) {
+                    if (error) {
+                        saveMessage.innerText = chrome.i18n.getMessage("options_save_failed");
+                        return;
+                    }
+
+                    sendMessage("changed");
+                });
             });
         });
     });
